@@ -79,9 +79,9 @@ def hc(data, method='standard', score='default', debug=False, alpha=0.4):
         :return: the learned BN
     '''
     if score == 'default':
-        if all(data[var].dtype.name == 'category' for var in data):
+        if all(data.dtypes == 'category'):
             score = 'bic'
-        elif all(data[var].dtype.name != 'category' for var in data):
+        elif all(data.dtypes != 'category'):
             score = 'bic_g'
         else:
             raise Exception('Mixed type of data is not supported yet.')
@@ -104,10 +104,7 @@ def hc(data, method='standard', score='default', debug=False, alpha=0.4):
         cache_weight = {}
         start_time = time.time()
         varnames = data.columns.tolist()
-        if method == 'pw':
-            cause_list = data.columns[data.isnull().any()].tolist()
-        else:
-            cause_list = find_causes(data)
+        cause_list = data.columns[data.isnull().any()].tolist() if method == 'pw' else find_causes(data)
         if all(data[var].dtype.name == 'category' for var in data):
             data = data.apply(lambda x: x.cat.codes).to_numpy()
         elif all(data[var].dtype.name != 'category' for var in data):
